# -*- coding:utf-8 -*-
from django.shortcuts import render_to_response, redirect
from django.template import RequestContext
from coop_tag.models import Ctag, CtaggedItem
from coop_local.models import Organization

# pourrait faire partie d'une appli coop-tags
def tag_detail(request,slug):
    context = {}
    tag = Ctag.objects.get(slug=slug)
    context['object'] = tag
    context['initiatives'] = Organization.objects.filter(tags=tag)    
    return render_to_response('tag_detail.html',context,RequestContext(request))




#!/usr/bin/env python
# -*- coding:utf-8 -*-
from django.conf.urls.defaults import patterns, url

urlpatterns = patterns('',
    url(r'^tag/(?P<slug>[\w-]+)/$', 'coop_tag.views.tag_detail', name="tag_detail"),
)



# -*- coding:utf-8 -*-
from django.contrib import admin
from coop_tag.models import Ctag,TagCategory

admin.site.register(TagCategory)


class TagAdmin(admin.ModelAdmin):
    search_fields = ['name','slug']
    list_filter = ('category',)

admin.site.register(Ctag,TagAdmin)



from django.forms.widgets import CheckboxSelectMultiple,CheckboxInput
from django.utils.encoding import force_unicode
from itertools import chain
from django.utils.safestring import mark_safe
from django.utils.html import conditional_escape

class GroupedCheckboxSelectMultiple(CheckboxSelectMultiple):
    class Media:
        js = ('js/autocolumn.js',)
    
    def render(self, name, value, attrs=None, choices=()):
        if value is None: value = []
        has_id = attrs and 'id' in attrs
        final_attrs = self.build_attrs(attrs, name=name)
        # Normalize to strings
        str_values = set([force_unicode(v) for v in value])
        output=[u'<div class="groupbox">']
        for z,g in enumerate(self.choices):
            output.append(u'<div class="groupbox-header">%s</div>' % g[0])
            output.append(u'<ul class="groupbox-list">')
            for i, (option_value, option_label) in enumerate(g[1]):
                # If an ID attribute was given, add a numeric index as a suffix,
                # so that the checkboxes don't all have the same ID attribute.
                if has_id:
                    final_attrs = dict(final_attrs, id='%s_%s_%s' % (attrs['id'],z, i))
                    label_for = u' for="%s"' % final_attrs['id']
                else:
                    label_for = ''

                cb = CheckboxInput(final_attrs, check_test=lambda value: value in str_values)
                option_value = force_unicode(option_value)
                rendered_cb = cb.render(name, option_value)
                option_label = conditional_escape(force_unicode(option_label))
                output.append(u'<li><label%s>%s %s</label></li>' % (label_for, rendered_cb, option_label))
            output.append(u'</ul>')
        output.append(u'</div>')
        return mark_safe(u'\n'.join(output))

    def id_for_label(self, id_):
        # See the comment for RadioSelect.id_for_label()
        if id_:
            id_ += '_0'
        return id_
    id_for_label = classmethod(id_for_label)


# -*- coding:utf-8 -*-
from django.db import models
from taggit.models import TagBase, GenericTaggedItemBase
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
from django_extensions.db import fields as exfields
from positions.fields import PositionField


class TagCategory(models.Model):
    label = models.CharField(_(u'label'), max_length=100)
    uri = models.CharField(_(u'tag URI'),blank=True,max_length=250,editable=False)
    slug    = exfields.AutoSlugField(populate_from='label',blank=True)
    position = PositionField()
    
    def __unicode__(self):
        return self.label
    class Meta:
        verbose_name = _(u'tag category')
        verbose_name_plural = _(u'tag categories')
        ordering = ['position']
        
    
class Ctag(TagBase):
    '''
    Defines a Common Tag resource
    '''
    # FIELDS name and slug are defined in TagBase    
    language    = models.CharField(_(u'language'),max_length=10, default='fr')
    user        = models.ForeignKey(User,blank=True,null=True,verbose_name=_(u'django user'),editable=False)
    uri         = models.CharField(_(u'tag URI'),blank=True,max_length=250,editable=False)
    author_uri  = models.CharField(_(u'author URI'),blank=True,max_length=250,editable=False)
    created     = exfields.CreationDateTimeField(_(u'created'))
    modified    = exfields.ModificationDateTimeField(_(u'modified'))
    category = models.ForeignKey(TagCategory,null=True,blank=True,verbose_name=_(u'category'))
    
    def get_absolute_url(self):
        return reverse('tag_detail', args=[self.slug])
    class Meta:
        verbose_name = _(u'tag')
        verbose_name_plural = _(u'tags') 
           
class CtaggedItem(GenericTaggedItemBase):
    tag = models.ForeignKey(Ctag, related_name="ctagged_items")
    class Meta:
        verbose_name = _(u'tagged item')
        verbose_name_plural = _(u'tagged items')




#!/usr/bin/env python
# -*- coding: utf-8 -*-

try:
    from setuptools import setup, find_packages
except ImportError:
    import ez_setup
    ez_setup.use_setuptools()
    from setuptools import setup, find_packages

VERSION = __import__('coop_tag').__version__

import os
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='coop-tag',
    version = VERSION,
    description='Add-on for django-coop for managing tags with django-taggit',
    packages=[  'coop_tag', 'coop_tag.migrations'],
    include_package_data=True,
    author='Cooperative Quinode',
    author_email='contact@quinode.fr',
    license='BSD',
    zip_safe=False,
    install_requires = ['django-taggit==0.9.3','django-positions==0.4.3'],
    long_description = open('README.rst').read(),
    url = 'https://github.com/quinode/coop-tag/',
    download_url = 'https://github.com/quinode/coop-tag/tarball/master',
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
        'Natural Language :: English',
        'Natural Language :: French',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
    ],

)

